Atmodeller Documentation
########################

| Lead author: Dan J. Bower
| Institute of Geochemistry and Petrology
| Department of Earth and Planetary Sciences
| ETH Zurich, Switzerland

*Atmodeller* is available at https://github.com/ExPlanetology/atmodeller. If you use *Atmodeller* please cite :cite:t:`BTT25`. An accompanying ArXiv preprint is available at `2507.00499 <https://arxiv.org/abs/2507.00499>`_.

Atmodeller was created as part of a SERI-funded ERC Starting grant '2ATMO' granted to P. Sossi (Contract no. MB22.00033), with additional funding provided through a Swiss National Science Foundation (SNSF) Eccellenza Professorship (#203668).

.. toctree::
   :maxdepth: 2
   :caption: User Guide

   about.rst
   installation.rst
   examples
   output.rst
   common_tasks.rst
   development.rst
   troubleshooting.rst

.. only:: html

   .. toctree::
      :maxdepth: 2
      :caption: Programmer Reference

      source/modules.rst

.. toctree::
   :caption: Bibliography

   bibliography.rst